package com.huiju.welcome.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.SysParam;
import com.huiju.welcome.service.ISysParamService;
import com.huiju.welcome.utils.StatusUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-14
 */
@RestController
@RequestMapping("/")
public class SysParamController {
    @Autowired
    private ISysParamService sysParamService;

    @ApiOperation(value = "修改系统参数", notes = "修改系统参数")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "String", name = "paramId", value = "参数ID"),
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "value", value = "参数值"),
    })
    @RequestMapping(value = "/sysparam/{paramId}", method = RequestMethod.PUT)
    public ResponseBean update(@PathVariable String paramId, @RequestBody String value, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        SysParam sysParam = sysParamService.getById(paramId);
        sysParam.setValue(value);

        boolean success = sysParamService.updateById(sysParam);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "更新内容失败");
            return responseBean;
        }

        return responseBean;
    }

    @ApiOperation(value = "获取系统参数详情", notes = "获取系统参数详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "String", name = "paramId", value = "参数ID"),
    })
    @RequestMapping(value = "/sysparam/{paramId}", method = RequestMethod.GET)
    public ResponseBean update(@PathVariable String paramId, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        SysParam sysParam = sysParamService.getById(paramId);
        responseBean.addSuccess(sysParam);

        return responseBean;
    }

    @ApiOperation(value = "获取系统参数列表", notes = "获取系统参数列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageNum", value = "当前页"),
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageSize", value = "每页数量"),
    })
    @RequestMapping(value = "/sysparam", method = RequestMethod.GET)
    public ResponseBean list(@RequestParam Integer pageNum, @RequestParam  Integer pageSize, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        Page<SysParam> pg = new Page<>();
        pg.setCurrent(pageNum);
        pg.setSize(pageSize);
        QueryWrapper<SysParam> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("param_id");
        queryWrapper.eq("status", StatusUtils.Normal);

        responseBean.addSuccess(sysParamService.page(pg, queryWrapper));

        return responseBean;
    }
}
